@@ -1,9 +1,4 @@
-use strict;
-use warnings;
-
 package App::Cmd::Command;
-use App::Cmd::ArgProcessor;
-BEGIN { our @ISA = 'App::Cmd::ArgProcessor' };
 
 =head1 NAME
 
@@ -11,56 +6,20 @@ App::Cmd::Command - a base class for App::Cmd commands
 
 =head1 VERSION
 
-version 0.299_01
+ $Id: /my/cs/projects/app-cmd/trunk/lib/App/Cmd/Command.pm 22432 2006-06-13T01:56:37.727054Z rjbs  $
 
 =cut
 
-our $VERSION = '0.299_01';
+use strict;
+use warnings;
 
 use Carp ();
 
 =head1 METHODS
 
-=head2 prepare
-
-  my ($cmd, $opt, $args) = $class->prepare($app, @args);
-
-This method is the primary way in which App::Cmd::Command objects are built.
-Given the remaining command line arguments meant for the command, it returns
-the Command object, parsed options (as a hashref), and remaining arguments (as
-an arrayref).
-
-In the usage above, C<$app> is the App::Cmd object that is invoking the
-command.
-
-=cut
-
-sub prepare {
-  my ($class, $app, @args) = @_;
-
-  my ($opt, $args, %fields)
-    = $class->_process_args(\@args, $class->_option_processing_params($app));
-
-  return (
-    $class->new({ app => $app, %fields }),
-    $opt,
-    @$args,
-  );
-}
-
-sub _option_processing_params {
-  my ($class, @args) = @_;
-
-  return (
-    $class->usage_desc(@args),
-    $class->opt_spec(@args),
-  );
-}
-
 =head2 new
 
-This returns a new instance of the command plugin.  Probably only C<prepare>
-should use this.
+This returns a new instance of the command plugin.
 
 =cut
 
@@ -69,31 +28,19 @@ sub new {
   bless $arg => $class;
 }
 
-=head2 execute
+=head2 run
 
-  $command_plugin->execute(\%opt, \@args);
+  $command_plugin->run($opt, $arg);
 
 This method does whatever it is the command should do!  It is passed a hash
 reference of the parsed command-line options and an array reference of left
 over arguments.
 
-If no C<execute> method is defined, it will try to call C<run> -- but it will
-warn about this behavior during testing, to remind you to fix the method name!
-
 =cut
 
-sub execute {
-  my $class = shift;
-  if ($class->can('run') and $ENV{HARNESS_ACTIVE}) {
-    warn "App::Cmd::Command subclasses should implement ->execute not ->run";
-  }
-
-  $class->run(@_);
-}
-
 sub run {
-  my $class = shift;
-  Carp::croak "$class does not implement mandatory method 'execute'\n";
+  my ($class) = @_;
+  Carp::croak "$class does not implement mandatory method 'run'\n";
 }
 
 =head2 app
@@ -143,8 +90,10 @@ the result of the C<command_names> method.
 sub usage_desc {
   my ($self) = @_;
 
+  my ($app) = $0 =~ m{([^/]+)$};
+  $app = 'COMMAND' unless defined $app;
   my ($command) = $self->command_names;
-  return "%c $command %o"
+  return "$app $command %o"
 }
 
 =head2 opt_spec
@@ -163,36 +112,16 @@ sub opt_spec {
 
 =head2 validate_args
 
-  $command_plugin->validate_args(\%opt, \@args);
+  $command_plugin->validate_args($opt, $arg);
 
 This method is passed a hashref of command line options (as processed by
 Getopt::Long::Descriptive) and an arrayref of leftover arguments.  It may throw
-an exception (preferably by calling C<usage_error>, below) if they are invalid,
-or it may do nothing to allow processing to continue.
+an exception if they are invalid, or may do nothing to allow processing to
+continue.
 
 =cut
 
-sub validate_args { }
-
-=head2 usage_error
-
-  $self->usage_error("This command must not be run by root!");
-
-This method should be called to die with human-friendly usage output, during
-C<validate_args>.
-
-=cut
-
-sub usage_error {
-  my ( $self, $error ) = @_;
-  die "Error: $error\nUsage: " . $self->_usage_text;
-}
-
-sub _usage_text {
-  my ($self) = @_;
-  local $@;
-  join "\n", eval { $self->app->_usage_text }, eval { $self->usage->text };
-}
+sub validate_args {}
 
 =head2 abstract
 
@@ -215,32 +144,20 @@ sub abstract {
   open my $fh, "<", $pm_file or return "(unknown)";
 
   local $/ = "\n";
-  my $inpod;
-
-  while (local $_ = <$fh>) {
-    $inpod = /^=cut/ ? !$inpod : $inpod || /^=(?!cut)/; # =cut toggles, it doesn't end :-/
-
+  my $inpod = 0;
+  while (<$fh>) {
+    $inpod = /^=(?!cut)/ ? 1
+           : /^=cut/     ? 0
+           :               $inpod;
     next unless $inpod;
     chomp;
-    next unless /^(?:$class\s-\s)(.*)/;
-    $result = $1;
+    next unless /^($class\s-\s)(.*)/;
+    $result = $2;
     last;
   }
   return $result || "(unknown)";
 }
 
-=head2 description
-
-This method should be overridden to provide full option description. It
-is used by the help command.
-
-If not overridden, it returns an empty string.
-
-=cut
-
-sub description { '' }
-
-
 =head1 AUTHOR AND COPYRIGHT
 
 See L<App::Cmd>.
